@@ -20,12 +20,19 @@ import os
 import sys
 import time
 from asyncio import Event
+from collections.abc import Mapping
 from pathlib import Path
 from typing import Final, TypedDict
 
-import orjson as json
 from get_version import get_version
 
+if sys.version_info >= (3, 12):
+    from . import orjson_temp_fix as json
+
+    sys.modules["orjson"] = json
+else:
+    import orjson as json
+
 try:
     from pytest_is_running import is_running as pytest_is_running
 except ImportError:
@@ -47,10 +54,12 @@ DIR: Final[str] = os.path.dirname(__file__)
 
 START_TIME_NS: Final[int] = time.monotonic_ns()
 
-MEDIA_TYPES: Final[dict[str, MediaType]] = json.loads(
+MEDIA_TYPES: Final[Mapping[str, MediaType]] = json.loads(
     Path(os.path.join(DIR, "media_types.json")).read_bytes()
 )
 
+assert "Í" not in str(MEDIA_TYPES)  # orjson is corrupting memory
+
 EPOCH: Final[int] = 1651075200
 EPOCH_MS: Final[int] = EPOCH * 1000
 
