@@ -17,14 +17,16 @@ from __future__ import annotations
 
 import os
 from functools import lru_cache
+from pathlib import Path
 from typing import Final, cast
 
 import orjson as json
+from typed_stream import FileStream, Stream
 
 DIR: Final = os.path.dirname(__file__)
 
 
-BASE_WORD_DIR: Final = os.path.join(DIR, "words")
+BASE_WORD_DIR: Final = Path(DIR) / "words"
 
 
 def get_filenames_and_languages() -> tuple[frozenset[str], frozenset[str]]:
@@ -34,25 +36,15 @@ def get_filenames_and_languages() -> tuple[frozenset[str], frozenset[str]]:
     The file names are each in a frozenset to guarantee immutability.
     """
     languages: set[str] = set()
-    filenames: set[str] = set()
-    # iterate over the folders in the words dir
-    for folder in os.listdir(BASE_WORD_DIR):
-        # check if the folder is a words folder
-        if folder.startswith("words_"):
-            # add the language found in the word dir to LANGUAGES
-            languages.add(folder[6:])  # without: "words_"
-            # the dir with the words in the current lang
-            words_dir = os.path.join(BASE_WORD_DIR, folder)
-            for filename in os.listdir(words_dir):
-                # ignore python files
-                if not filename.endswith(".py"):
-                    # the relativ file name
-                    rel_filename = f"{folder}/{filename}"
-
-                    # add the file name without the extension to filenames
-                    filenames.add(rel_filename.split(".", 1)[0])
-
-    return frozenset(filenames), frozenset(languages)
+    return frozenset(
+        Stream(BASE_WORD_DIR.iterdir())
+        .filter(Path.is_dir)
+        .filter(lambda folder: folder.name != "__pycache__")
+        .peek(lambda folder: languages.add(folder.name))
+        .flat_map(lambda folder: folder.glob("[0123456789]*.json"))
+        .map(lambda file: file.relative_to(BASE_WORD_DIR).with_suffix(""))
+        .map(str)
+    ), frozenset(languages)
 
 
 FILE_NAMES, LANGUAGES = get_filenames_and_languages()
@@ -61,17 +53,13 @@ FILE_NAMES, LANGUAGES = get_filenames_and_languages()
 @lru_cache(10)
 def get_words(filename: str) -> frozenset[str]:
     """Get the words with the filename and return them."""
-    with open(
-        os.path.join(BASE_WORD_DIR, f"{filename}.txt"), encoding="UTF-8"
-    ) as file:
-        return frozenset(file.read().splitlines())
+    return frozenset(
+        FileStream(BASE_WORD_DIR / f"{filename}.txt").map(str.rstrip)
+    )
 
 
 @lru_cache(10)
 def get_letters(filename: str) -> dict[str, int]:
     """Get the letters dict with the filename and return it."""
-    with open(
-        os.path.join(BASE_WORD_DIR, f"{filename}.json"), encoding="UTF-8"
-    ) as file:
-        # we know the files, so we know the type
-        return cast(dict[str, int], json.loads(file.read()))
+    file = BASE_WORD_DIR / f"{filename}.json"
+    return cast(dict[str, int], json.loads(file.read_text(encoding="UTF-8")))
