@@ -15,6 +15,7 @@
 
 from __future__ import annotations
 
+import abc
 import asyncio
 import contextlib
 import logging
@@ -22,7 +23,7 @@ import os
 import random
 import sys
 import time
-from collections.abc import Callable, Iterable, Mapping
+from collections.abc import Callable, Iterable, Mapping, Sequence
 from dataclasses import dataclass
 from datetime import date, datetime
 from multiprocessing import Value
@@ -64,11 +65,12 @@ MAX_AUTHORS_ID = Value("Q", 0)
 
 
 @dataclass(init=False, slots=True)
-class QuotesObjBase:
+class QuotesObjBase(abc.ABC):
     """An object with an id."""
 
     id: int  # pylint: disable=invalid-name
 
+    @abc.abstractmethod
     async def fetch_new_data(self) -> QuotesObjBase:
         """Fetch new data from the API."""
         raise NotImplementedError
@@ -78,6 +80,11 @@ class QuotesObjBase:
         """Get the id of the object as a string."""
         return str(self.id)
 
+    @abc.abstractmethod
+    def get_path(self) -> str:
+        """Return the path to the Object."""
+        raise NotImplementedError
+
 
 @dataclass(slots=True)
 class Author(QuotesObjBase):
@@ -99,12 +106,16 @@ class Author(QuotesObjBase):
         """Fetch new data from the API."""
         return parse_author(await make_api_request(f"authors/{self.id}"))
 
+    def get_path(self) -> str:
+        """Return the path to the author info."""
+        return f"/zitate/info/a/{self.id}"
+
     def to_json(self) -> dict[str, Any]:
         """Get the author as JSON."""
         return {
             "id": self.id,
             "name": str(self),
-            "path": f"/zitate/info/a/{self.id}",
+            "path": self.get_path(),
             "info": {
                 "source": self.info[0],
                 "text": self.info[1],
@@ -142,13 +153,17 @@ class Quote(QuotesObjBase):
         """Fetch new data from the API."""
         return parse_quote(await make_api_request(f"quotes/{self.id}"), self)
 
+    def get_path(self) -> str:
+        """Return the path to the quote info."""
+        return f"/zitate/info/z/{self.id}"
+
     def to_json(self) -> dict[str, Any]:
         """Get the quote as JSON."""
         return {
             "id": self.id,
             "quote": str(self),
             "author": self.author.to_json(),
-            "path": f"/zitate/info/z/{self.id}",
+            "path": self.get_path(),
         }
 
     def update_quote(
@@ -215,6 +230,10 @@ class WrongQuote(QuotesObjBase):
             return str(self.id)
         return f"{self.quote.id}-{self.author.id}"
 
+    def get_path(self) -> str:
+        """Return the path to the wrong quote."""
+        return f"/zitate/{self.get_id_as_str()}"
+
     def to_json(self) -> dict[str, Any]:
         """Get the wrong quote as JSON."""
         return {
@@ -222,7 +241,7 @@ class WrongQuote(QuotesObjBase):
             "quote": self.quote.to_json(),
             "author": self.author.to_json(),
             "rating": self.rating,
-            "path": f"/zitate/{self.get_id_as_str()}",
+            "path": self.get_path(),
         }
 
     async def vote(
@@ -258,7 +277,7 @@ def get_wrong_quotes(
     sort: bool = False,  # sorted by rating
     filter_real_quotes: bool = True,
     shuffle: bool = False,
-) -> tuple[WrongQuote, ...]:
+) -> Sequence[WrongQuote]:
     """Get cached wrong quotes."""
     if shuffle and sort:
         raise ValueError("Sort and shuffle can't be both true.")
@@ -276,7 +295,7 @@ def get_wrong_quotes(
         random.shuffle(wqs_list)
     if sort:
         wqs_list.sort(key=lambda wq: wq.rating, reverse=True)
-    return tuple(wqs_list)
+    return wqs_list
 
 
 def get_quotes(
@@ -474,7 +493,7 @@ async def update_cache_periodically(app: Application) -> None:  # noqa: C901
         await asyncio.wait_for(EVENT_REDIS.wait(), 5)
     redis: Redis[str] = cast("Redis[str]", app.settings.get("REDIS"))
     prefix: str = app.settings.get("REDIS_PREFIX", NAME).removesuffix("-dev")
-    apm: None | elasticapm.Client
+    apm: None | elasticapm.Client  # type: ignore[no-any-unimported]
     if EVENT_REDIS.is_set():  # pylint: disable=too-many-nested-blocks
         parse_list_of_quote_data(
             await redis.get(f"{prefix}:cached-quote-data:wrongquotes"),  # type: ignore[arg-type]  # noqa: B950  # pylint: disable=line-too-long, useless-suppression
